@@ -4,15 +4,18 @@ from __future__ import with_statement
 
 import sys
 import json
-from recoder.builder.builder import Builder
-from recoder.pyver import *
+from .builder import Builder
+from ..pyver import *
 
 coding = sys.argv[1] if len(sys.argv) > 1 else 'utf-8'
 
 if pyver == 2:
     input_data = sys.stdin.read().decode(coding, errors='ignore')
 elif pyver == 3:
-    input_data = sys.stdin.buffer.read().decode(coding, errors='ignore')
+    if len(sys.argv) == 1:
+        input_data = sys.stdin.read()
+    else:
+        input_data = sys.stdin.buffer.read().decode(coding, errors='ignore')
 
 builder = Builder()
 
