@@ -1,7 +1,9 @@
 # -*- coding: utf-8 -*-
 
-from recoder.pyver import *
-import regex
+from __future__ import unicode_literals
+
+import re
+from ..pyver import *
 
 class Builder(object):
     def __init__(self, plus_words_count=30, grams_count=10000):
@@ -19,20 +21,11 @@ class Builder(object):
 
     def build_plus_words(self, unicode_text):
         unicode_text = unicode_text.lower()
-
-        if pyver == 2:
-            unicode_text = regex.sub('\W'.decode('utf-8'), ' '.decode('utf-8'), unicode_text, regex.U)
-            unicode_text = regex.sub('[\d_]'.decode('utf-8'), ' '.decode('utf-8'), unicode_text, regex.U)
-            unicode_text = regex.sub('\s+'.decode('utf-8'), ' '.decode('utf-8'), unicode_text, regex.U).strip()
-            words = regex.split('\s+'.decode('utf-8'), unicode_text)
-        elif pyver == 3:
-            unicode_text = regex.sub('\W', ' ', unicode_text, regex.U)
-            unicode_text = regex.sub('[\d_]', ' ', unicode_text, regex.U)
-            unicode_text = regex.sub('\s+', ' ', unicode_text, regex.U).strip()
-            words = regex.split('\s+', unicode_text)
+        filtered_text = ''.join(map(lambda c: (c if c.isalpha() else ' '), unicode_text)).strip()
+        words = re.split('\s+', filtered_text)
 
         plus_words = {}
         for word in words:
             plus_words[word] = plus_words.get(word, 0) + 1
         top_words = sorted(plus_words.items(), key=lambda item: item[1], reverse=True)[:self.plus_words_count]
-        return dict(top_words).keys()
\ No newline at end of file
+        return list(dict(top_words).keys())
\ No newline at end of file
