@@ -1,14 +1,12 @@
 # -*- coding: utf-8 -*-
 
+from __future__ import unicode_literals
+
 import unittest
-from recoder import cyrillic
-from recoder.pyver import *
+from . import cyrillic
 
 class TestMain(unittest.TestCase):
-    if pyver == 2:
-        sample_text = 'какой-то текст для примера работы библиотеки'.decode('utf-8')
-    elif pyver == 3:
-        sample_text = 'какой-то текст для примера работы библиотеки'
+    sample_text = 'какой-то текст для примера работы библиотеки'
 
     cyr_recoder = cyrillic.Recoder()
 
